==> kubernetes-model-admissionregistration-5.3.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/authorization/v1beta1/SubjectRulesReviewStatusFluent.java <==
package io.fabric8.kubernetes.api.model.authorization.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface SubjectRulesReviewStatusFluent<A extends io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectRulesReviewStatusFluent<A>> extends Fluent<A> {


    public String getEvaluationError();
    public A withEvaluationError(String evaluationError);
    public Boolean hasEvaluationError();
    public A withNewEvaluationError(StringBuilder arg1);
    public A withNewEvaluationError(int[] arg1,int arg2,int arg3);
    public A withNewEvaluationError(char[] arg1);
    public A withNewEvaluationError(StringBuffer arg1);
    public A withNewEvaluationError(byte[] arg1,int arg2);
    public A withNewEvaluationError(byte[] arg1);
    public A withNewEvaluationError(char[] arg1,int arg2,int arg3);
    public A withNewEvaluationError(byte[] arg1,int arg2,int arg3);
    public A withNewEvaluationError(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewEvaluationError(String arg1);
    public Boolean getIncomplete();
    public A withIncomplete(Boolean incomplete);
    public Boolean hasIncomplete();
    public A withNewIncomplete(String arg1);
    public A withNewIncomplete(boolean arg1);
    public A addToNonResourceRules(int index,io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceRule item);
    public A setToNonResourceRules(int index,io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceRule item);
    public A addToNonResourceRules(io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceRule... items);
    public A addAllToNonResourceRules(Collection<io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceRule> items);
    public A removeFromNonResourceRules(io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceRule... items);
    public A removeAllFromNonResourceRules(Collection<io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceRule> items);
    public A removeMatchingFromNonResourceRules(Predicate<io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceRuleBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildNonResourceRules instead.
 * @return The buildable object.
 */
@Deprecated public List<io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceRule> getNonResourceRules();
    public List<io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceRule> buildNonResourceRules();
    public io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceRule buildNonResourceRule(int index);
    public io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceRule buildFirstNonResourceRule();
    public io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceRule buildLastNonResourceRule();
    public io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceRule buildMatchingNonResourceRule(Predicate<io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceRuleBuilder> predicate);
    public Boolean hasMatchingNonResourceRule(Predicate<io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceRuleBuilder> predicate);
    public A withNonResourceRules(List<io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceRule> nonResourceRules);
    public A withNonResourceRules(io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceRule... nonResourceRules);
    public Boolean hasNonResourceRules();
    public SubjectRulesReviewStatusFluent.NonResourceRulesNested<A> addNewNonResourceRule();
    public SubjectRulesReviewStatusFluent.NonResourceRulesNested<A> addNewNonResourceRuleLike(io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceRule item);
    public SubjectRulesReviewStatusFluent.NonResourceRulesNested<A> setNewNonResourceRuleLike(int index,io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceRule item);
    public SubjectRulesReviewStatusFluent.NonResourceRulesNested<A> editNonResourceRule(int index);
    public SubjectRulesReviewStatusFluent.NonResourceRulesNested<A> editFirstNonResourceRule();
    public SubjectRulesReviewStatusFluent.NonResourceRulesNested<A> editLastNonResourceRule();
    public SubjectRulesReviewStatusFluent.NonResourceRulesNested<A> editMatchingNonResourceRule(Predicate<io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceRuleBuilder> predicate);
    public A addToResourceRules(int index,io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRule item);
    public A setToResourceRules(int index,io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRule item);
    public A addToResourceRules(io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRule... items);
    public A addAllToResourceRules(Collection<io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRule> items);
    public A removeFromResourceRules(io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRule... items);
    public A removeAllFromResourceRules(Collection<io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRule> items);
    public A removeMatchingFromResourceRules(Predicate<io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRuleBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildResourceRules instead.
 * @return The buildable object.
 */
@Deprecated public List<io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRule> getResourceRules();
    public List<io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRule> buildResourceRules();
    public io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRule buildResourceRule(int index);
    public io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRule buildFirstResourceRule();
    public io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRule buildLastResourceRule();
    public io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRule buildMatchingResourceRule(Predicate<io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRuleBuilder> predicate);
    public Boolean hasMatchingResourceRule(Predicate<io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRuleBuilder> predicate);
    public A withResourceRules(List<io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRule> resourceRules);
    public A withResourceRules(io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRule... resourceRules);
    public Boolean hasResourceRules();
    public SubjectRulesReviewStatusFluent.ResourceRulesNested<A> addNewResourceRule();
    public SubjectRulesReviewStatusFluent.ResourceRulesNested<A> addNewResourceRuleLike(io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRule item);
    public SubjectRulesReviewStatusFluent.ResourceRulesNested<A> setNewResourceRuleLike(int index,io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRule item);
    public SubjectRulesReviewStatusFluent.ResourceRulesNested<A> editResourceRule(int index);
    public SubjectRulesReviewStatusFluent.ResourceRulesNested<A> editFirstResourceRule();
    public SubjectRulesReviewStatusFluent.ResourceRulesNested<A> editLastResourceRule();
    public SubjectRulesReviewStatusFluent.ResourceRulesNested<A> editMatchingResourceRule(Predicate<io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRuleBuilder> predicate);
    public interface NonResourceRulesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceRuleFluent<SubjectRulesReviewStatusFluent.NonResourceRulesNested<N>> {

            public N and();
            public N endNonResourceRule();    }


    public interface ResourceRulesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRuleFluent<SubjectRulesReviewStatusFluent.ResourceRulesNested<N>> {

            public N and();
            public N endResourceRule();    }


}

==> kubernetes-model-admissionregistration-5.3.1-sources.jar: annotations/io/fabric8/kubernetes/api/model/authorization/v1beta1/SubjectRulesReviewStatusFluent.java <==
package io.fabric8.kubernetes.api.model.authorization.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface SubjectRulesReviewStatusFluent<A extends io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectRulesReviewStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public String getEvaluationError();
    public A withEvaluationError(String evaluationError);
    public Boolean hasEvaluationError();
    public A withNewEvaluationError(StringBuilder arg1);
    public A withNewEvaluationError(int[] arg1,int arg2,int arg3);
    public A withNewEvaluationError(char[] arg1);
    public A withNewEvaluationError(StringBuffer arg1);
    public A withNewEvaluationError(byte[] arg1,int arg2);
    public A withNewEvaluationError(byte[] arg1);
    public A withNewEvaluationError(char[] arg1,int arg2,int arg3);
    public A withNewEvaluationError(byte[] arg1,int arg2,int arg3);
    public A withNewEvaluationError(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewEvaluationError(String arg1);
    public Boolean getIncomplete();
    public A withIncomplete(Boolean incomplete);
    public Boolean hasIncomplete();
    public A withNewIncomplete(String arg1);
    public A withNewIncomplete(boolean arg1);
    public A addToNonResourceRules(int index,io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceRule item);
    public A setToNonResourceRules(int index,io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceRule item);
    public A addToNonResourceRules(io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceRule... items);
    public A addAllToNonResourceRules(Collection<io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceRule> items);
    public A removeFromNonResourceRules(io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceRule... items);
    public A removeAllFromNonResourceRules(Collection<io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceRule> items);
    public A removeMatchingFromNonResourceRules(Predicate<io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceRuleBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildNonResourceRules instead.
 * @return The buildable object.
 */
@Deprecated public List<io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceRule> getNonResourceRules();
    public List<io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceRule> buildNonResourceRules();
    public io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceRule buildNonResourceRule(int index);
    public io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceRule buildFirstNonResourceRule();
    public io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceRule buildLastNonResourceRule();
    public io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceRule buildMatchingNonResourceRule(Predicate<io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceRuleBuilder> predicate);
    public Boolean hasMatchingNonResourceRule(Predicate<io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceRuleBuilder> predicate);
    public A withNonResourceRules(List<io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceRule> nonResourceRules);
    public A withNonResourceRules(io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceRule... nonResourceRules);
    public Boolean hasNonResourceRules();
    public io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectRulesReviewStatusFluent.NonResourceRulesNested<A> addNewNonResourceRule();
    public io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectRulesReviewStatusFluent.NonResourceRulesNested<A> addNewNonResourceRuleLike(io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceRule item);
    public io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectRulesReviewStatusFluent.NonResourceRulesNested<A> setNewNonResourceRuleLike(int index,io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceRule item);
    public io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectRulesReviewStatusFluent.NonResourceRulesNested<A> editNonResourceRule(int index);
    public io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectRulesReviewStatusFluent.NonResourceRulesNested<A> editFirstNonResourceRule();
    public io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectRulesReviewStatusFluent.NonResourceRulesNested<A> editLastNonResourceRule();
    public io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectRulesReviewStatusFluent.NonResourceRulesNested<A> editMatchingNonResourceRule(Predicate<io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceRuleBuilder> predicate);
    public A addToResourceRules(int index,io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRule item);
    public A setToResourceRules(int index,io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRule item);
    public A addToResourceRules(io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRule... items);
    public A addAllToResourceRules(Collection<io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRule> items);
    public A removeFromResourceRules(io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRule... items);
    public A removeAllFromResourceRules(Collection<io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRule> items);
    public A removeMatchingFromResourceRules(Predicate<io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRuleBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildResourceRules instead.
 * @return The buildable object.
 */
@Deprecated public List<io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRule> getResourceRules();
    public List<io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRule> buildResourceRules();
    public io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRule buildResourceRule(int index);
    public io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRule buildFirstResourceRule();
    public io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRule buildLastResourceRule();
    public io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRule buildMatchingResourceRule(Predicate<io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRuleBuilder> predicate);
    public Boolean hasMatchingResourceRule(Predicate<io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRuleBuilder> predicate);
    public A withResourceRules(List<io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRule> resourceRules);
    public A withResourceRules(io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRule... resourceRules);
    public Boolean hasResourceRules();
    public io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectRulesReviewStatusFluent.ResourceRulesNested<A> addNewResourceRule();
    public io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectRulesReviewStatusFluent.ResourceRulesNested<A> addNewResourceRuleLike(io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRule item);
    public io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectRulesReviewStatusFluent.ResourceRulesNested<A> setNewResourceRuleLike(int index,io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRule item);
    public io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectRulesReviewStatusFluent.ResourceRulesNested<A> editResourceRule(int index);
    public io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectRulesReviewStatusFluent.ResourceRulesNested<A> editFirstResourceRule();
    public io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectRulesReviewStatusFluent.ResourceRulesNested<A> editLastResourceRule();
    public io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectRulesReviewStatusFluent.ResourceRulesNested<A> editMatchingResourceRule(Predicate<io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRuleBuilder> predicate);
    public interface NonResourceRulesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.authorization.v1beta1.NonResourceRuleFluent<io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectRulesReviewStatusFluent.NonResourceRulesNested<N>> {

            public N and();
            public N endNonResourceRule();    }


    public interface ResourceRulesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.authorization.v1beta1.ResourceRuleFluent<io.fabric8.kubernetes.api.model.authorization.v1beta1.SubjectRulesReviewStatusFluent.ResourceRulesNested<N>> {

            public N and();
            public N endResourceRule();    }


}
